Extensions - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Extensions

Betty’s functionality can be altered using extensions. An extension can do many things, such as loading new or expanding existing ancestry data, or generating additional content for your site.

Some extensions are configurable. That means that other than enabling them, you can set the configuration options that determine how the extension should work. This can be done in your project’s configuration file.

## In this section

- The Cotton Candy extension

- The Deriver extension

- The Gramps extension

- The HTTP API Documentation extension

- The Maps extension

- The nginx extension

- The Privatizer extension

- The Trees extension

- The Wikipedia extension

## See also

- Developing a Betty extension